==> qmmp_1.1.4.orig.tar.bz2: qmmp-1.1.4/src/plugins/Engines/mplayer/translations/mplayer_plugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name>MplayerEngineFactory</name>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="34"/>
        <source>Mplayer Plugin</source>
        <translation>Módulo MPlayer</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="37"/>
        <source>Video Files</source>
        <translation>Archivos de vídeo</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="83"/>
        <source>About MPlayer Plugin</source>
        <translation>Acerca del módulo MPlayer</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="84"/>
        <source>Qmmp MPlayer Plugin</source>
        <translation>Modulo MPlayer para Qmmp</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="85"/>
        <source>This plugin uses MPlayer as backend</source>
        <translation>Este módulo utiliza MPlayer como soporte</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="86"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Escrito por: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>MplayerMetaDataModel</name>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="38"/>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="38"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="75"/>
        <source>Length</source>
        <translation>Duración</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="77"/>
        <source>Demuxer</source>
        <translation>Demultiplexador</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="80"/>
        <source>Video format</source>
        <translation>Formato de vídeo</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="82"/>
        <source>FPS</source>
        <translation>FPS</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="84"/>
        <source>Video codec</source>
        <translation>Códec de vídeo</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="86"/>
        <source>Aspect ratio</source>
        <translation>Proporción de imagen</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="88"/>
        <source>Video bitrate</source>
        <translation>Tasa de bits de vídeo</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="95"/>
        <source>Audio codec</source>
        <translation>Códec de sonido</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="97"/>
        <source>Sample rate</source>
        <translation>Frecuencia</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="99"/>
        <source>Audio bitrate</source>
        <translation>Tasa de bits de sonido</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="101"/>
        <source>Channels</source>
        <translation>Canales</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="103"/>
        <source>Resolution</source>
        <translation>Resolución</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="29"/>
        <location filename="../settingsdialog.cpp" line="37"/>
        <location filename="../settingsdialog.cpp" line="46"/>
        <location filename="../settingsdialog.cpp" line="47"/>
        <location filename="../settingsdialog.cpp" line="61"/>
        <location filename="../settingsdialog.cpp" line="62"/>
        <source>default</source>
        <translation>predeterminado</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>MPlayer Settings</source>
        <translation>Configuración de MPlayer</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source>Video:</source>
        <translation>Vídeo:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Audio:</source>
        <translation>Imagen:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="72"/>
        <source>Synchronization factor:</source>
        <translation>Factor de sincronización</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="89"/>
        <source>Extra options:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="96"/>
        <source>Extra command line options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Audio/video auto synchronization</source>
        <translation>Sincronización imagen/sonido</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/Engines/mplayer/translations/mplayer_plugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name>MplayerEngineFactory</name>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="34"/>
        <source>Mplayer Plugin</source>
        <translation>Módulo MPlayer</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="37"/>
        <source>Video Files</source>
        <translation>Archivos de vídeo</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="83"/>
        <source>About MPlayer Plugin</source>
        <translation>Acerca del módulo MPlayer</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="84"/>
        <source>Qmmp MPlayer Plugin</source>
        <translation>Modulo MPlayer para Qmmp</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="85"/>
        <source>This plugin uses MPlayer as backend</source>
        <translation>Este módulo utiliza MPlayer como soporte</translation>
    </message>
    <message>
        <location filename="../mplayerenginefactory.cpp" line="86"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Escrito por: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>MplayerMetaDataModel</name>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="38"/>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="38"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="75"/>
        <source>Length</source>
        <translation>Duración</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="77"/>
        <source>Demuxer</source>
        <translation>Demultiplexador</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="80"/>
        <source>Video format</source>
        <translation>Formato de vídeo</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="82"/>
        <source>FPS</source>
        <translation>FPS</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="84"/>
        <source>Video codec</source>
        <translation>Códec de vídeo</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="86"/>
        <source>Aspect ratio</source>
        <translation>Proporción de imagen</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="88"/>
        <source>Video bitrate</source>
        <translation>Tasa de bits de vídeo</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="95"/>
        <source>Audio codec</source>
        <translation>Códec de sonido</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="97"/>
        <source>Sample rate</source>
        <translation>Frecuencia</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="99"/>
        <source>Audio bitrate</source>
        <translation>Tasa de bits de sonido</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="101"/>
        <source>Channels</source>
        <translation>Canales</translation>
    </message>
    <message>
        <location filename="../mplayermetadatamodel.cpp" line="103"/>
        <source>Resolution</source>
        <translation>Resolución</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>MPlayer Settings</source>
        <translation>Configuración de MPlayer</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source>Video:</source>
        <translation>Vídeo:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Audio:</source>
        <translation>Imagen:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Audio/video auto synchronization</source>
        <translation>Sincronización imagen/sonido</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="72"/>
        <source>Synchronization factor:</source>
        <translation>Factor de sincronización</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="89"/>
        <source>Extra options:</source>
        <translation>Opciones extras:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="96"/>
        <source>Extra command line options</source>
        <translation>Opciones extras de consola</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="29"/>
        <location filename="../settingsdialog.cpp" line="37"/>
        <location filename="../settingsdialog.cpp" line="46"/>
        <location filename="../settingsdialog.cpp" line="47"/>
        <location filename="../settingsdialog.cpp" line="61"/>
        <location filename="../settingsdialog.cpp" line="62"/>
        <source>default</source>
        <translation>predeterminado</translation>
    </message>
</context>
</TS>
